==> jc-1.4.0.tar.gz: java/awt/Window__24AccessibleAWTWindow.h <==
// public class java.awt.Window$AccessibleAWTWindow

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2e728272befbb849 java_awt_Window__24AccessibleAWTWindow
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Container__24AccessibleAWTContainer

#include "java/awt/Container__24AccessibleAWTContainer.h"

#ifndef _JC_java_awt_Window__24AccessibleAWTWindow_H_
#define _JC_java_awt_Window__24AccessibleAWTWindow_H_

// Forward structure declarations
struct _jc_java_awt_Window$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs	_jc_java_awt_Window__24AccessibleAWTWindow$sub_refs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs	_jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$refs	_jc_java_awt_Window__24AccessibleAWTWindow$refs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$nonrefs	_jc_java_awt_Window__24AccessibleAWTWindow$nonrefs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$object	_jc_java_awt_Window__24AccessibleAWTWindow$object;

typedef const struct _jc_java_awt_Window__24AccessibleAWTWindow$vmethods	_jc_java_awt_Window__24AccessibleAWTWindow$vmethods;
typedef const struct _jc_java_awt_Window__24AccessibleAWTWindow$vtable	_jc_java_awt_Window__24AccessibleAWTWindow$vtable;
typedef const struct _jc_java_awt_Window__24AccessibleAWTWindow$vtype	_jc_java_awt_Window__24AccessibleAWTWindow$vtype;

// Constructors
extern void _jc_java_awt_Window__24AccessibleAWTWindow$method$_init$2efbec8a054b9293(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *, struct _jc_java_awt_Window$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Window__24AccessibleAWTWindow$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_Window__24AccessibleAWTWindow$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Window__24AccessibleAWTWindow$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_Window__24AccessibleAWTWindow$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_Window__24AccessibleAWTWindow$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *);
};

// Vtable
struct _jc_java_awt_Window__24AccessibleAWTWindow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Window__24AccessibleAWTWindow$vmethods	java_awt_Window__24AccessibleAWTWindow;
};

// Vtype
struct _jc_java_awt_Window__24AccessibleAWTWindow$vtype {
	_jc_type			type;
	_jc_java_awt_Window__24AccessibleAWTWindow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs {
	struct _jc_java_awt_Window$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Window__24AccessibleAWTWindow$refs {
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs	java_awt_Window__24AccessibleAWTWindow;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Window__24AccessibleAWTWindow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs	java_awt_Window__24AccessibleAWTWindow;
};

// Object instance structure
struct _jc_java_awt_Window__24AccessibleAWTWindow$object {
	_jc_java_awt_Window__24AccessibleAWTWindow$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Window__24AccessibleAWTWindow$vtype	*vtype;
	_jc_java_awt_Window__24AccessibleAWTWindow$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Window__24AccessibleAWTWindow$vtype _jc_java_awt_Window__24AccessibleAWTWindow$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Window__24AccessibleAWTWindow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Window__24AccessibleAWTWindow$class_object;

#endif	/* _JC_java_awt_Window__24AccessibleAWTWindow_H_ */

==> jc-1.4.5.tar.gz: java/awt/Window__24AccessibleAWTWindow.h <==
// public class java.awt.Window$AccessibleAWTWindow

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 7c1da994418530e9 java_awt_Window__24AccessibleAWTWindow
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Container__24AccessibleAWTContainer

#include "java/awt/Container__24AccessibleAWTContainer.h"

#ifndef _JC_java_awt_Window__24AccessibleAWTWindow_H_
#define _JC_java_awt_Window__24AccessibleAWTWindow_H_

// Forward structure declarations
struct _jc_java_awt_Window$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs	_jc_java_awt_Window__24AccessibleAWTWindow$sub_refs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs	_jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$refs	_jc_java_awt_Window__24AccessibleAWTWindow$refs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$nonrefs	_jc_java_awt_Window__24AccessibleAWTWindow$nonrefs;
typedef struct _jc_java_awt_Window__24AccessibleAWTWindow$object	_jc_java_awt_Window__24AccessibleAWTWindow$object;

typedef const struct _jc_java_awt_Window__24AccessibleAWTWindow$vmethods	_jc_java_awt_Window__24AccessibleAWTWindow$vmethods;
typedef const struct _jc_java_awt_Window__24AccessibleAWTWindow$vtable	_jc_java_awt_Window__24AccessibleAWTWindow$vtable;
typedef const struct _jc_java_awt_Window__24AccessibleAWTWindow$vtype	_jc_java_awt_Window__24AccessibleAWTWindow$vtype;

// Constructors
extern void _jc_java_awt_Window__24AccessibleAWTWindow$method$_init$2efbec8a054b9293(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *, struct _jc_java_awt_Window$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Window__24AccessibleAWTWindow$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_Window__24AccessibleAWTWindow$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Window__24AccessibleAWTWindow$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_Window__24AccessibleAWTWindow$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_Window__24AccessibleAWTWindow$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_Window__24AccessibleAWTWindow$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Window__24AccessibleAWTWindow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Window__24AccessibleAWTWindow$vmethods	java_awt_Window__24AccessibleAWTWindow;
};

// Vtype
struct _jc_java_awt_Window__24AccessibleAWTWindow$vtype {
	_jc_type			type;
	_jc_java_awt_Window__24AccessibleAWTWindow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs {
	struct _jc_java_awt_Window$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Window__24AccessibleAWTWindow$refs {
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_refs	java_awt_Window__24AccessibleAWTWindow;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Window__24AccessibleAWTWindow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Window__24AccessibleAWTWindow$sub_nonrefs	java_awt_Window__24AccessibleAWTWindow;
};

// Object instance structure
struct _jc_java_awt_Window__24AccessibleAWTWindow$object {
	_jc_java_awt_Window__24AccessibleAWTWindow$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Window__24AccessibleAWTWindow$vtype	*vtype;
	_jc_java_awt_Window__24AccessibleAWTWindow$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Window__24AccessibleAWTWindow$vtype _jc_java_awt_Window__24AccessibleAWTWindow$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Window__24AccessibleAWTWindow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Window__24AccessibleAWTWindow$class_object;

#endif	/* _JC_java_awt_Window__24AccessibleAWTWindow_H_ */
